This is the mail archive of the java-patches@gcc.gnu.org mailing list for the Java project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

FYI: Patch: move of protocol handlers


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Hi list,



I committed the attched patch to move the protocol handlers from 
gnu.gcj.protocol to gnu.java.net.protocol to make it possible to 
merge them with classpath later.


Michael
- -- 
Homepage: http://www.worldforge.org/
-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.2.3 (GNU/Linux)

iD8DBQE/hDxtWSOgCCdjSDsRAlOVAJ0SdJiyjOY4w3NBdO2Us5r6rEG10wCeNatt
yECqkH9pmwboRj1IzE8rWIs=
=+j9z
-----END PGP SIGNATURE-----
Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/libjava/ChangeLog,v
retrieving revision 1.2219
diff -u -b -B -r1.2219 ChangeLog
--- ChangeLog	8 Oct 2003 15:30:44 -0000	1.2219
+++ ChangeLog	8 Oct 2003 16:26:19 -0000
@@ -1,5 +1,38 @@
 2003-10-08  Michael Koch  <konqueror@gmx.de>
 
+	* gnu/gcj/protocol/core/Connection.java,
+	gnu/gcj/protocol/core/CoreInputStream.java,
+	gnu/gcj/protocol/core/Handler.java,
+	gnu/gcj/protocol/core/natCoreInputStream.cc,
+	gnu/gcj/protocol/file/Connection.java,
+	gnu/gcj/protocol/file/Handler.java,
+	gnu/gcj/protocol/gcjlib/Connection.java,
+	gnu/gcj/protocol/gcjlib/Handler.java,
+	gnu/gcj/protocol/http/Connection.java,
+	gnu/gcj/protocol/http/Handler.java,
+	gnu/gcj/protocol/jar/Connection.java,
+	gnu/gcj/protocol/jar/Handler.java: Moved to gnu/java/net/protocol.
+	* gnu/java/net/protocol/core/Connection.java,
+	gnu/java/net/protocol/core/CoreInputStream.java,
+	gnu/java/net/protocol/core/Handler.java,
+	gnu/java/net/protocol/core/natCoreInputStream.cc,
+	gnu/java/net/protocol/file/Connection.java,
+	gnu/java/net/protocol/file/Handler.java,
+	gnu/java/net/protocol/gcjlib/Connection.java,
+	gnu/java/net/protocol/gcjlib/Handler.java,
+	gnu/java/net/protocol/http/Connection.java,
+	gnu/java/net/protocol/http/Handler.java,
+	gnu/java/net/protocol/jar/Connection.java,
+	gnu/java/net/protocol/jar/Handler.java: Moved from gnu/gcj/protocol.
+	* gnu/gcj/runtime/FirstThread.java,
+	java/net/URL.java: Use moved protocol handlers.
+	* Makefile.am
+	(ordinary_java_source_files): Moved files.
+	(nat_source_files): Likewise.
+	* Makefile.in: Regenerated.
+
+2003-10-08  Michael Koch  <konqueror@gmx.de>
+
 	* java/util/LinkedList.java:
 	Removed whitespace to match classpath's version again.
 
Index: Makefile.am
===================================================================
RCS file: /cvs/gcc/gcc/libjava/Makefile.am,v
retrieving revision 1.328
diff -u -b -B -r1.328 Makefile.am
--- Makefile.am	25 Sep 2003 21:14:43 -0000	1.328
+++ Makefile.am	8 Oct 2003 16:26:21 -0000
@@ -2009,17 +2009,6 @@
 gnu/gcj/io/DefaultMimeTypes.java \
 gnu/gcj/io/MimeTypes.java \
 gnu/gcj/io/SimpleSHSStream.java	\
-gnu/gcj/protocol/core/Connection.java \
-gnu/gcj/protocol/core/Handler.java \
-gnu/gcj/protocol/core/CoreInputStream.java \
-gnu/gcj/protocol/file/Connection.java \
-gnu/gcj/protocol/file/Handler.java \
-gnu/gcj/protocol/http/Connection.java \
-gnu/gcj/protocol/http/Handler.java \
-gnu/gcj/protocol/jar/Connection.java \
-gnu/gcj/protocol/jar/Handler.java \
-gnu/gcj/protocol/gcjlib/Connection.java \
-gnu/gcj/protocol/gcjlib/Handler.java \
 gnu/gcj/runtime/FileDeleter.java \
 gnu/gcj/runtime/FinalizerThread.java \
 gnu/gcj/runtime/FirstThread.java \
@@ -2182,6 +2171,17 @@
 gnu/java/math/MPN.java \
 gnu/java/net/PlainDatagramSocketImpl.java \
 gnu/java/net/PlainSocketImpl.java \
+gnu/java/net/protocol/core/Connection.java \
+gnu/java/net/protocol/core/Handler.java \
+gnu/java/net/protocol/core/CoreInputStream.java \
+gnu/java/net/protocol/file/Connection.java \
+gnu/java/net/protocol/file/Handler.java \
+gnu/java/net/protocol/http/Connection.java \
+gnu/java/net/protocol/http/Handler.java \
+gnu/java/net/protocol/jar/Connection.java \
+gnu/java/net/protocol/jar/Handler.java \
+gnu/java/net/protocol/gcjlib/Connection.java \
+gnu/java/net/protocol/gcjlib/Handler.java \
 gnu/java/nio/DatagramChannelImpl.java \
 gnu/java/nio/DatagramChannelSelectionKey.java \
 gnu/java/nio/FileLockImpl.java \
@@ -2645,7 +2645,6 @@
 gnu/gcj/convert/natOutput_SJIS.cc \
 gnu/gcj/io/natSimpleSHSStream.cc \
 gnu/gcj/io/shs.cc \
-gnu/gcj/protocol/core/natCoreInputStream.cc \
 gnu/gcj/runtime/natFinalizerThread.cc \
 gnu/gcj/runtime/natFirstThread.cc \
 gnu/gcj/runtime/natNameFinder.cc \
@@ -2656,6 +2655,7 @@
 gnu/java/awt/natEmbeddedWindow.cc \
 gnu/java/net/natPlainDatagramSocketImpl.cc \
 gnu/java/net/natPlainSocketImpl.cc \
+gnu/java/net/protocol/core/natCoreInputStream.cc \
 gnu/java/nio/natFileLockImpl.cc \
 gnu/java/nio/natSelectorImpl.cc \
 java/io/natFile.cc \
Index: Makefile.in
===================================================================
RCS file: /cvs/gcc/gcc/libjava/Makefile.in,v
retrieving revision 1.352
diff -u -b -B -r1.352 Makefile.in
--- Makefile.in	25 Sep 2003 21:14:43 -0000	1.352
+++ Makefile.in	8 Oct 2003 16:26:24 -0000
@@ -1727,17 +1728,6 @@
 gnu/gcj/io/DefaultMimeTypes.java \
 gnu/gcj/io/MimeTypes.java \
 gnu/gcj/io/SimpleSHSStream.java	\
-gnu/gcj/protocol/core/Connection.java \
-gnu/gcj/protocol/core/Handler.java \
-gnu/gcj/protocol/core/CoreInputStream.java \
-gnu/gcj/protocol/file/Connection.java \
-gnu/gcj/protocol/file/Handler.java \
-gnu/gcj/protocol/http/Connection.java \
-gnu/gcj/protocol/http/Handler.java \
-gnu/gcj/protocol/jar/Connection.java \
-gnu/gcj/protocol/jar/Handler.java \
-gnu/gcj/protocol/gcjlib/Connection.java \
-gnu/gcj/protocol/gcjlib/Handler.java \
 gnu/gcj/runtime/FileDeleter.java \
 gnu/gcj/runtime/FinalizerThread.java \
 gnu/gcj/runtime/FirstThread.java \
@@ -1900,6 +1890,17 @@
 gnu/java/math/MPN.java \
 gnu/java/net/PlainDatagramSocketImpl.java \
 gnu/java/net/PlainSocketImpl.java \
+gnu/java/net/protocol/core/Connection.java \
+gnu/java/net/protocol/core/Handler.java \
+gnu/java/net/protocol/core/CoreInputStream.java \
+gnu/java/net/protocol/file/Connection.java \
+gnu/java/net/protocol/file/Handler.java \
+gnu/java/net/protocol/http/Connection.java \
+gnu/java/net/protocol/http/Handler.java \
+gnu/java/net/protocol/jar/Connection.java \
+gnu/java/net/protocol/jar/Handler.java \
+gnu/java/net/protocol/gcjlib/Connection.java \
+gnu/java/net/protocol/gcjlib/Handler.java \
 gnu/java/nio/DatagramChannelImpl.java \
 gnu/java/nio/DatagramChannelSelectionKey.java \
 gnu/java/nio/FileLockImpl.java \
@@ -2362,7 +2363,6 @@
 gnu/gcj/convert/natOutput_SJIS.cc \
 gnu/gcj/io/natSimpleSHSStream.cc \
 gnu/gcj/io/shs.cc \
-gnu/gcj/protocol/core/natCoreInputStream.cc \
 gnu/gcj/runtime/natFinalizerThread.cc \
 gnu/gcj/runtime/natFirstThread.cc \
 gnu/gcj/runtime/natNameFinder.cc \
@@ -2373,6 +2373,7 @@
 gnu/java/awt/natEmbeddedWindow.cc \
 gnu/java/net/natPlainDatagramSocketImpl.cc \
 gnu/java/net/natPlainSocketImpl.cc \
+gnu/java/net/protocol/core/natCoreInputStream.cc \
 gnu/java/nio/natFileLockImpl.cc \
 gnu/java/nio/natSelectorImpl.cc \
 java/io/natFile.cc \
@@ -2543,20 +2544,21 @@
 gnu/gcj/convert/natIconv.lo gnu/gcj/convert/natInput_EUCJIS.lo \
 gnu/gcj/convert/natInput_SJIS.lo gnu/gcj/convert/natOutput_EUCJIS.lo \
 gnu/gcj/convert/natOutput_SJIS.lo gnu/gcj/io/natSimpleSHSStream.lo \
-gnu/gcj/io/shs.lo gnu/gcj/protocol/core/natCoreInputStream.lo \
-gnu/gcj/runtime/natFinalizerThread.lo gnu/gcj/runtime/natFirstThread.lo \
-gnu/gcj/runtime/natNameFinder.lo gnu/gcj/runtime/natSharedLibLoader.lo \
-gnu/gcj/runtime/natStackTrace.lo gnu/gcj/runtime/natStringBuffer.lo \
-gnu/gcj/runtime/natVMClassLoader.lo gnu/java/awt/natEmbeddedWindow.lo \
+gnu/gcj/io/shs.lo gnu/gcj/runtime/natFinalizerThread.lo \
+gnu/gcj/runtime/natFirstThread.lo gnu/gcj/runtime/natNameFinder.lo \
+gnu/gcj/runtime/natSharedLibLoader.lo gnu/gcj/runtime/natStackTrace.lo \
+gnu/gcj/runtime/natStringBuffer.lo gnu/gcj/runtime/natVMClassLoader.lo \
+gnu/java/awt/natEmbeddedWindow.lo \
 gnu/java/net/natPlainDatagramSocketImpl.lo \
-gnu/java/net/natPlainSocketImpl.lo gnu/java/nio/natFileLockImpl.lo \
-gnu/java/nio/natSelectorImpl.lo java/io/natFile.lo \
-java/io/natFileDescriptor.lo java/io/natObjectInputStream.lo \
-java/io/natVMObjectStreamClass.lo java/lang/natCharacter.lo \
-java/lang/natClass.lo java/lang/natClassLoader.lo \
-java/lang/natConcreteProcess.lo java/lang/natDouble.lo \
-java/lang/natFloat.lo java/lang/natMath.lo java/lang/natObject.lo \
-java/lang/natRuntime.lo java/lang/natString.lo \
+gnu/java/net/natPlainSocketImpl.lo \
+gnu/java/net/protocol/core/natCoreInputStream.lo \
+gnu/java/nio/natFileLockImpl.lo gnu/java/nio/natSelectorImpl.lo \
+java/io/natFile.lo java/io/natFileDescriptor.lo \
+java/io/natObjectInputStream.lo java/io/natVMObjectStreamClass.lo \
+java/lang/natCharacter.lo java/lang/natClass.lo \
+java/lang/natClassLoader.lo java/lang/natConcreteProcess.lo \
+java/lang/natDouble.lo java/lang/natFloat.lo java/lang/natMath.lo \
+java/lang/natObject.lo java/lang/natRuntime.lo java/lang/natString.lo \
 java/lang/natStringBuffer.lo java/lang/natSystem.lo \
 java/lang/natThread.lo java/lang/natVMSecurityManager.lo \
 java/lang/ref/natReference.lo java/lang/reflect/natArray.lo \
@@ -2766,19 +2768,7 @@
 .deps/gnu/gcj/io/DefaultMimeTypes.P .deps/gnu/gcj/io/MimeTypes.P \
 .deps/gnu/gcj/io/SimpleSHSStream.P \
 .deps/gnu/gcj/io/natSimpleSHSStream.P .deps/gnu/gcj/io/shs.P \
-.deps/gnu/gcj/natCore.P .deps/gnu/gcj/protocol/core/Connection.P \
-.deps/gnu/gcj/protocol/core/CoreInputStream.P \
-.deps/gnu/gcj/protocol/core/Handler.P \
-.deps/gnu/gcj/protocol/core/natCoreInputStream.P \
-.deps/gnu/gcj/protocol/file/Connection.P \
-.deps/gnu/gcj/protocol/file/Handler.P \
-.deps/gnu/gcj/protocol/gcjlib/Connection.P \
-.deps/gnu/gcj/protocol/gcjlib/Handler.P \
-.deps/gnu/gcj/protocol/http/Connection.P \
-.deps/gnu/gcj/protocol/http/Handler.P \
-.deps/gnu/gcj/protocol/jar/Connection.P \
-.deps/gnu/gcj/protocol/jar/Handler.P \
-.deps/gnu/gcj/runtime/FileDeleter.P \
+.deps/gnu/gcj/natCore.P .deps/gnu/gcj/runtime/FileDeleter.P \
 .deps/gnu/gcj/runtime/FinalizerThread.P \
 .deps/gnu/gcj/runtime/FirstThread.P .deps/gnu/gcj/runtime/JNIWeakRef.P \
 .deps/gnu/gcj/runtime/MethodRef.P .deps/gnu/gcj/runtime/NameFinder.P \
@@ -3027,6 +3017,18 @@
 .deps/gnu/java/net/PlainSocketImpl.P \
 .deps/gnu/java/net/natPlainDatagramSocketImpl.P \
 .deps/gnu/java/net/natPlainSocketImpl.P \
+.deps/gnu/java/net/protocol/core/Connection.P \
+.deps/gnu/java/net/protocol/core/CoreInputStream.P \
+.deps/gnu/java/net/protocol/core/Handler.P \
+.deps/gnu/java/net/protocol/core/natCoreInputStream.P \
+.deps/gnu/java/net/protocol/file/Connection.P \
+.deps/gnu/java/net/protocol/file/Handler.P \
+.deps/gnu/java/net/protocol/gcjlib/Connection.P \
+.deps/gnu/java/net/protocol/gcjlib/Handler.P \
+.deps/gnu/java/net/protocol/http/Connection.P \
+.deps/gnu/java/net/protocol/http/Handler.P \
+.deps/gnu/java/net/protocol/jar/Connection.P \
+.deps/gnu/java/net/protocol/jar/Handler.P \
 .deps/gnu/java/nio/DatagramChannelImpl.P \
 .deps/gnu/java/nio/DatagramChannelSelectionKey.P \
 .deps/gnu/java/nio/FileLockImpl.P .deps/gnu/java/nio/NIOConstants.P \
Index: gnu/gcj/protocol/core/Connection.java
===================================================================
RCS file: gnu/gcj/protocol/core/Connection.java
diff -N gnu/gcj/protocol/core/Connection.java
--- gnu/gcj/protocol/core/Connection.java	28 Aug 2003 22:17:35 -0000	1.3
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,169 +0,0 @@
-// Connection.java - Implementation of URLConnection for core protocol.
-
-/* Copyright (C) 2001, 2003  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.core;
-
-import gnu.gcj.Core;
-import java.net.*;
-import java.io.*;
-import java.util.Map;
-import java.util.Vector;
-import java.util.Hashtable;
-import java.util.Enumeration;
-
-/**
- * @author Anthony Green <green@redhat.com>
- * @date August 13, 2001
- */
-
-class Connection extends URLConnection
-{
-  private Hashtable hdrHash = new Hashtable();
-  private Vector hdrVec = new Vector();
-  private boolean gotHeaders = false;
-
-  private Core core;
-
-  public Connection(URL url)
-  {
-    super(url);
-  }
-
-  // Implementation of abstract method.
-  public void connect() throws IOException
-  {
-    // Call is ignored if already connected.
-    if (connected)
-      return;
-
-    // If not connected, then file needs to be opened.
-    core = Core.create (url.getFile());
-    connected = true;
-  }
-
-  public InputStream getInputStream() throws IOException
-  {
-    if (!connected)
-      connect();
-
-    if (! doInput)
-      throw new ProtocolException("Can't open InputStream if doInput is false");
-    return new CoreInputStream (core);
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderField(String name)
-  {
-    try
-      {
-	getHeaders();
-      }
-    catch (IOException x)
-      {
-	return null;
-      }
-    return (String) hdrHash.get(name.toLowerCase());
-  }
-
-  // Override default method in URLConnection.
-  public Map getHeaderFields()
-  {
-    try
-      {
-	getHeaders();
-      }
-    catch (IOException x)
-      {
-	return null;
-      }
-    return hdrHash;
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderField(int n)
-  {
-    try
-      {
-	getHeaders();
-      }
-    catch (IOException x)
-      {
-	return null;
-      }
-    if (n < hdrVec.size())
-      return getField((String) hdrVec.elementAt(n));
-
-    return null;
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderFieldKey(int n)
-  {
-    try
-      {
-	getHeaders();
-      }
-    catch (IOException x)
-      {
-	return null;
-      }
-    if (n < hdrVec.size())
-      return getKey((String) hdrVec.elementAt(n));
-
-    return null;
-  }
-
-  private String getKey(String str)
-  {
-    if (str == null)
-      return null;
-    int index = str.indexOf(':');
-    if (index >= 0)
-      return str.substring(0, index);
-    else
-      return null;
-  }
-
-  private String getField(String str)
-  {
-    if (str == null)
-      return null;
-    int index = str.indexOf(':');
-    if (index >= 0)
-      return str.substring(index + 1).trim();
-    else
-      return str;
-  }
-
-  private void getHeaders() throws IOException
-  {
-    if (gotHeaders)
-      return;
-    gotHeaders = true;
-
-    connect();
-
-    // Yes, it is overkill to use the hash table and vector here since
-    // we're only putting one header in the file, but in case we need
-    // to add others later and for consistency, we'll implement it this way.
-
-    // Add the only header we know about right now:  Content-length.
-    long len = core.length;
-    String line = "Content-length: " + len;
-    hdrVec.addElement(line);
-
-    // The key will never be null in this scenario since we build up the
-    // headers ourselves.  If we ever rely on getting a header from somewhere
-    // else, then we may have to check if the result of getKey() is null.
-    String key = getKey(line);
-    hdrHash.put(key.toLowerCase(), Long.toString(len));
-  }
-}
-
Index: gnu/gcj/protocol/core/CoreInputStream.java
===================================================================
RCS file: gnu/gcj/protocol/core/CoreInputStream.java
diff -N gnu/gcj/protocol/core/CoreInputStream.java
--- gnu/gcj/protocol/core/CoreInputStream.java	6 Sep 2001 22:32:54 -0000	1.1
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,89 +0,0 @@
-// Handler.java - URLStreamHandler for core protocol.
-
-/* Copyright (C) 2001  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.core;
-
-import java.io.*;
-import gnu.gcj.Core;
-import gnu.gcj.RawData;
-
-public class CoreInputStream extends InputStream
-{
-  /* A pointer to the object in memory.  */
-  protected RawData ptr;
-
-  /* Position of the next byte in core to be read. */
-  protected int pos;
-
-  /* The currently marked position in the stream. */
-  protected int mark;
-
-  /* The index in core one greater than the last valid character. */
-  protected int count;
-
-  private native int unsafeGetByte (long offset);
-  private native int copyIntoByteArray (byte[] dest, int offset, int numBytes);
-
-  public CoreInputStream (Core core)
-  {
-    ptr = core.ptr;
-    count = core.length;
-  }
-
-  public synchronized int available()
-  {
-    return count - pos;
-  }
-
-  public synchronized void mark(int readAheadLimit)
-  {
-    // readAheadLimit is ignored per Java Class Lib. book, p.220.
-    mark = pos;
-  }
-
-  public boolean markSupported()
-  {
-    return true;
-  }
-
-  public synchronized int read()
-  {
-    if (pos < count)
-      return ((int) unsafeGetByte(pos++)) & 0xFF;
-    return -1;
-  }
-
-  public synchronized int read(byte[] b, int off, int len)
-  {
-    if (pos >= count)
-      return -1;
-
-    int numBytes = Math.min(count - pos, len);
-    copyIntoByteArray (b, off, numBytes);
-    pos += numBytes;
-    return numBytes;
-  }
-
-  public synchronized void reset()
-  {
-    pos = mark;
-  }
-
-  public synchronized long skip(long n)
-  {
-    // Even though the var numBytes is a long, in reality it can never
-    // be larger than an int since the result of subtracting 2 positive
-    // ints will always fit in an int.  Since we have to return a long
-    // anyway, numBytes might as well just be a long.
-    long numBytes = Math.min((long) (count - pos), n < 0 ? 0L : n);
-    pos += numBytes;
-    return numBytes;
-  }
-}
Index: gnu/gcj/protocol/core/Handler.java
===================================================================
RCS file: gnu/gcj/protocol/core/Handler.java
diff -N gnu/gcj/protocol/core/Handler.java
--- gnu/gcj/protocol/core/Handler.java	6 Sep 2001 22:32:54 -0000	1.1
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,29 +0,0 @@
-// Handler.java - URLStreamHandler for core protocol.
-
-/* Copyright (C) 2001  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.core;
-
-import java.net.URL;
-import java.net.URLConnection;
-import java.net.URLStreamHandler;
-import java.io.IOException;
-
-/**
- * @author Anthony Green <green@redhat.com>
- * @date August 13, 2001.
- */
-
-public class Handler extends URLStreamHandler
-{
-  protected URLConnection openConnection(URL url) throws IOException
-  {
-    return new Connection(url);
-  }
-}
Index: gnu/gcj/protocol/core/natCoreInputStream.cc
===================================================================
RCS file: gnu/gcj/protocol/core/natCoreInputStream.cc
diff -N gnu/gcj/protocol/core/natCoreInputStream.cc
--- gnu/gcj/protocol/core/natCoreInputStream.cc	6 Sep 2001 22:32:54 -0000	1.1
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,49 +0,0 @@
-// natCoreInputStream.cc -- C++ side of CoreInputStream
-
-/* Copyright (C) 2001  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-/* Author: Anthony Green <green@redhat.com>.  */
-
-#include <config.h>
-
-#include <gcj/cni.h>
-#include <jvm.h>
-#include <string.h>
-
-#include <java/lang/NullPointerException.h>
-#include <java/lang/ArrayIndexOutOfBoundsException.h>
-#include <gnu/gcj/protocol/core/CoreInputStream.h>
-
-jint
-gnu::gcj::protocol::core::CoreInputStream::unsafeGetByte (jlong offset)
-{
-  return ((char *)ptr)[offset];
-}
-
-jint
-gnu::gcj::protocol::core::CoreInputStream::copyIntoByteArray (jbyteArray dest,
-							      jint offset,
-							      jint numBytes)
-{
-  if (! dest)
-    throw new java::lang::NullPointerException; 
-  jsize destSize = JvGetArrayLength (dest);
-  if (offset < 0 || numBytes < 0 || offset + numBytes < 0
-      || offset + numBytes > destSize
-      || pos + numBytes > count)
-    throw new java::lang::ArrayIndexOutOfBoundsException;
-
-  void *pcore = (void *) &((char*)ptr)[pos];
-  void *pdest = (void *) (elements (dest) + offset);
-
-  memcpy (pdest, pcore, numBytes);
-
-  return 0;
-}
-
Index: gnu/gcj/protocol/file/Connection.java
===================================================================
RCS file: gnu/gcj/protocol/file/Connection.java
diff -N gnu/gcj/protocol/file/Connection.java
--- gnu/gcj/protocol/file/Connection.java	23 Aug 2002 04:54:02 -0000	1.6
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,192 +0,0 @@
-// Connection.java - Implementation of URLConnection for file protocol.
-
-/* Copyright (C) 1999  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.file;
-
-import java.net.*;
-import java.io.*;
-import java.util.Map;
-import java.util.Vector;
-import java.util.Hashtable;
-import java.util.Enumeration;
-
-/**
- * @author Warren Levy <warrenl@cygnus.com>
- * @date April 13, 1999.
- */
-
-/**
- * Written using on-line Java Platform 1.2 API Specification, as well
- * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
- * Status:  Minimal subset of functionality.
- */
-
-class Connection extends URLConnection
-{
-  private Hashtable hdrHash = new Hashtable();
-  private Vector hdrVec = new Vector();
-  private boolean gotHeaders = false;
-  private File fileIn;
-  private InputStream inputStream;
-  private OutputStream outputStream;
-
-  public Connection(URL url)
-  {
-    super(url);
-  }
-
-  // Implementation of abstract method.
-  public void connect() throws IOException
-  {
-    // Call is ignored if already connected.
-    if (connected)
-      return;
-
-    // If not connected, then file needs to be openned.
-    String fname = url.getFile();
-    fileIn = new File(fname);
-    if (doInput)
-      inputStream = new BufferedInputStream(new FileInputStream(fileIn));
-    if (doOutput)
-      outputStream = new BufferedOutputStream(new FileOutputStream(fileIn));
-    connected = true;
-  }
-
-  public InputStream getInputStream() throws IOException
-  {
-    if (! doInput)
-      throw new ProtocolException("Can't open InputStream if doInput is false");
-    if (!connected)
-      connect();
-
-    return inputStream;
-  }
-
-  // Override default method in URLConnection.
-  public OutputStream getOutputStream() throws IOException
-  {
-    if (! doOutput)
-      throw new
-	ProtocolException("Can't open OutputStream if doOutput is false");
-
-    if (!connected)
-      connect();
-
-    return outputStream;
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderField(String name)
-  {
-    try
-      {
-	getHeaders();
-      }
-    catch (IOException x)
-      {
-	return null;
-      }
-    return (String) hdrHash.get(name.toLowerCase());
-  }
-
-  // Override default method in URLConnection.
-  public Map getHeaderFields()
-  {
-    try
-      {
-	getHeaders();
-      }
-    catch (IOException x)
-      {
-	return null;
-      }
-    return hdrHash;
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderField(int n)
-  {
-    try
-      {
-	getHeaders();
-      }
-    catch (IOException x)
-      {
-	return null;
-      }
-    if (n < hdrVec.size())
-      return getField((String) hdrVec.elementAt(n));
-
-    return null;
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderFieldKey(int n)
-  {
-    try
-      {
-	getHeaders();
-      }
-    catch (IOException x)
-      {
-	return null;
-      }
-    if (n < hdrVec.size())
-      return getKey((String) hdrVec.elementAt(n));
-
-    return null;
-  }
-
-  private String getKey(String str)
-  {
-    if (str == null)
-      return null;
-    int index = str.indexOf(':');
-    if (index >= 0)
-      return str.substring(0, index);
-    else
-      return null;
-  }
-
-  private String getField(String str)
-  {
-    if (str == null)
-      return null;
-    int index = str.indexOf(':');
-    if (index >= 0)
-      return str.substring(index + 1).trim();
-    else
-      return str;
-  }
-
-  private void getHeaders() throws IOException
-  {
-    if (gotHeaders)
-      return;
-    gotHeaders = true;
-
-    connect();
-
-    // Yes, it is overkill to use the hash table and vector here since
-    // we're only putting one header in the file, but in case we need
-    // to add others later and for consistency, we'll implement it this way.
-
-    // Add the only header we know about right now:  Content-length.
-    long len = fileIn.length();
-    String line = "Content-length: " + len;
-    hdrVec.addElement(line);
-
-    // The key will never be null in this scenario since we build up the
-    // headers ourselves.  If we ever rely on getting a header from somewhere
-    // else, then we may have to check if the result of getKey() is null.
-    String key = getKey(line);
-    hdrHash.put(key.toLowerCase(), Long.toString(len));
-  }
-}
Index: gnu/gcj/protocol/file/Handler.java
===================================================================
RCS file: gnu/gcj/protocol/file/Handler.java
diff -N gnu/gcj/protocol/file/Handler.java
--- gnu/gcj/protocol/file/Handler.java	30 Sep 2001 07:52:16 -0000	1.6
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,53 +0,0 @@
-// Handler.java - URLStreamHandler for file protocol.
-
-/* Copyright (C) 1999, 2000  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.file;
-
-import java.net.URL;
-import java.net.URLConnection;
-import java.net.URLStreamHandler;
-import java.io.IOException;
-
-/**
- * @author Warren Levy <warrenl@cygnus.com>
- * @date April 13, 1999.
- */
-
-/**
- * Written using on-line Java Platform 1.2 API Specification, as well
- * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
- * Status:  Minimal functionality.
- */
-
-public class Handler extends URLStreamHandler
-{
-  protected URLConnection openConnection(URL url) throws IOException
-  {
-    // If a hostname is set, then we need to switch protocols to ftp
-    // in order to transfer this from the remote host.
-    String host = url.getHost();
-    if ((host != null) && (! host.equals("")))
-      {
-        throw new IOException("ftp protocol handler not yet implemented.");
-        /*
-	// Reset the protocol (and implicitly the handler) for this URL.
-	// Then have the URL attempt the connection again, as it will
-	// get the changed handler the next time around.
-	setURL (url, "ftp", url.getHost(), url.getPort(), url.getFile(),
-		url.getRef());
-	// Until the ftp protocol handler is written, this will cause
-	// a NullPointerException.
-	return url.openConnection();
-	*/
-      }
-
-    return new Connection(url);
-  }
-}
Index: gnu/gcj/protocol/gcjlib/Connection.java
===================================================================
RCS file: gnu/gcj/protocol/gcjlib/Connection.java
diff -N gnu/gcj/protocol/gcjlib/Connection.java
--- gnu/gcj/protocol/gcjlib/Connection.java	28 Aug 2003 22:17:36 -0000	1.1
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,60 +0,0 @@
-// Connection.java - Implementation of URLConnection for gcjlib
-// protocol.
-
-/* Copyright (C) 2003  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.gcjlib;
-import java.io.*;
-import java.net.*;
-import gnu.gcj.Core;
-import gnu.gcj.protocol.core.CoreInputStream;
-import gnu.gcj.runtime.SharedLibHelper;
-
-/**
- * @author Tom Tromey <tromey@redhat.com>
- * @date January 10, 2003
- */
-
-class Connection extends URLConnection
-{
-  String solib;
-  String name;
-  Core core;
-
-  public Connection (URL url) throws MalformedURLException
-  {
-    super (url);
-    int index = url.getFile().indexOf("!/");
-    if (index == -1)
-      throw new MalformedURLException("couldn't find !/ in gcjlib URL");
-
-    name = url.getFile().substring(index + 2);
-    solib = url.getFile().substring(0, index);
-  }
-
-  public void connect() throws IOException
-  {
-    if (core != null)
-      return;
-    // We can't create a new SharedLibHelper here, since we don't know
-    // what parent class loader to use.
-    SharedLibHelper helper = SharedLibHelper.findHelper(solib);
-    if (helper == null)
-      throw new IOException("library not loaded: " + solib);
-    core = helper.findCore(name);
-    if (core == null)
-      throw new IOException("couldn't find core object: " + name);
-  }
-
-  public InputStream getInputStream() throws IOException
-  {
-    connect();
-    return new CoreInputStream(core);
-  }
-}
Index: gnu/gcj/protocol/gcjlib/Handler.java
===================================================================
RCS file: gnu/gcj/protocol/gcjlib/Handler.java
diff -N gnu/gcj/protocol/gcjlib/Handler.java
--- gnu/gcj/protocol/gcjlib/Handler.java	28 Aug 2003 22:17:36 -0000	1.1
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,24 +0,0 @@
-// Handler.java - URLStreamHandler for gcjlib protocol.
-
-/* Copyright (C) 2003  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.gcjlib;
-
-import java.net.URL;
-import java.net.URLConnection;
-import java.net.URLStreamHandler;
-import java.io.IOException;
-
-public class Handler extends URLStreamHandler
-{
-  protected URLConnection openConnection(URL url) throws IOException
-  {
-    return new Connection(url);
-  }
-}
Index: gnu/gcj/protocol/http/Connection.java
===================================================================
RCS file: gnu/gcj/protocol/http/Connection.java
diff -N gnu/gcj/protocol/http/Connection.java
--- gnu/gcj/protocol/http/Connection.java	3 Jan 2003 18:05:00 -0000	1.8
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,340 +0,0 @@
-// Connection.java - Implementation of HttpURLConnection for http protocol.
-
-/* Copyright (C) 1999, 2000, 2003  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.http;
-
-import java.net.*;
-import java.io.*;
-import java.util.Map;
-import java.util.Vector;
-import java.util.Hashtable;
-import java.util.Enumeration;
-
-/**
- * @author Warren Levy <warrenl@cygnus.com>
- * @date March 29, 1999.
- */
-
-/**
- * Written using on-line Java Platform 1.2 API Specification, as well
- * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
- * Status: Minimal subset of functionality.  Proxies only partially
- * handled; Redirects not yet handled.  FileNameMap handling needs to
- * be considered.  useCaches, ifModifiedSince, and
- * allowUserInteraction need consideration as well as doInput and
- * doOutput.
- */
-
-class Connection extends HttpURLConnection
-{
-  protected Socket sock = null;
-  private static Hashtable defRequestProperties = new Hashtable();
-  private Hashtable requestProperties;
-  private Hashtable hdrHash = new Hashtable();
-  private Vector hdrVec = new Vector();
-  private BufferedInputStream bufferedIn;
-
-  private static int proxyPort = 80;
-  private static boolean proxyInUse = false;
-  private static String proxyHost = null;
-
-  static 
-  {
-    // Recognize some networking properties listed at
-    // http://java.sun.com/j2se/1.4/docs/guide/net/properties.html.
-    String port = null;
-    proxyHost = System.getProperty("http.proxyHost");
-    if (proxyHost != null)
-      {
-	proxyInUse = true;
-	if ((port = System.getProperty("http.proxyPort")) != null)
-	  {
-	    try
-	      {
-		proxyPort = Integer.parseInt(port);
-	      }
-	    catch (Throwable t)
-	      {
-		// Nothing.  
-	      }
-	  }
-      }
-  }
-
-  public Connection(URL url)
-  {
-    super(url);
-    requestProperties = (Hashtable) defRequestProperties.clone();
-  }
-
-  // Override method in URLConnection.
-  public static void setDefaultRequestProperty(String key, String value)
-  {
-    defRequestProperties.put(key, value);
-  }
-
-  // Override method in URLConnection.
-  public static String getDefaultRequestProperty(String key)
-  {
-    return (String) defRequestProperties.get(key);
-  }
-
-  // Override method in URLConnection.
-  public void setRequestProperty(String key, String value)
-  {
-    if (connected)
-      throw new IllegalAccessError("Connection already established.");
-
-    requestProperties.put(key, value);
-  }
-
-  // Override method in URLConnection.
-  public String getRequestProperty(String key)
-  {
-    if (connected)
-      throw new IllegalAccessError("Connection already established.");
-
-    return (String) requestProperties.get(key);
-  }
-
-  // Implementation of abstract method.
-  public void connect() throws IOException
-  {
-    // Call is ignored if already connected.
-    if (connected)
-      return;
-
-    // Get address and port number.
-    int port;
-    if (proxyInUse)
-      {
-	port = proxyPort;
-	sock = new Socket(proxyHost, port);
-      }
-    else
-      {
-	InetAddress destAddr = InetAddress.getByName(url.getHost());
-	if ((port = url.getPort()) == -1)
-	  port = 80;
-	// Open socket and output stream.
-	sock = new Socket(destAddr, port);
-      }
-
-    PrintWriter out = new PrintWriter(sock.getOutputStream());
-
-    // Send request including any request properties that were set.
-    out.print(getRequestMethod() + " " + url.getFile() + " HTTP/1.0\n");
-    out.print("Host: " + url.getHost() + ":" + port + "\n");
-    Enumeration reqKeys = requestProperties.keys();
-    Enumeration reqVals = requestProperties.elements();
-    while (reqKeys.hasMoreElements())
-      out.print(reqKeys.nextElement() + ": " + reqVals.nextElement() + "\n");
-    out.print("\n");
-    out.flush();    
-    getHttpHeaders();
-    connected = true;
-  }
-
-  // Implementation of abstract method.
-  public void disconnect()
-  {
-    if (sock != null)
-      {
-	try
-	  {
-	    sock.close();
-	  }
-	catch (IOException ex)
-	  {
-	    ; // Ignore errors in closing socket.
-	  }
-	sock = null;
-      }
-  }
-
-  public boolean usingProxy()
-  {
-    return proxyInUse;
-  }
-
-  // Override default method in URLConnection.
-  public InputStream getInputStream() throws IOException
-  {
-    if (!connected)
-      connect();
-
-    if (!doInput)
-      throw new ProtocolException("Can't open InputStream if doInput is false");
-    return bufferedIn;
-  }
-
-  // Override default method in URLConnection.
-  public OutputStream getOutputStream() throws IOException
-  {
-    if (!connected)
-      connect();
-
-    if (! doOutput)
-      throw new
-	ProtocolException("Can't open OutputStream if doOutput is false");
-    return sock.getOutputStream();
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderField(String name)
-  {
-    if (!connected)
-      try
-        {
-	  connect();
-	}
-      catch (IOException x)
-        {
-	  return null;
-	}
-
-    return (String) hdrHash.get(name.toLowerCase());
-  }
-
-  // Override default method in URLConnection.
-  public Map getHeaderFields()
-  {
-    if (!connected)
-      try
-        {
-	  connect();
-	}
-      catch (IOException x)
-        {
-	  return null;
-	}
-
-    return hdrHash;
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderField(int n)
-  {
-    if (!connected)
-      try
-        {
-	  connect();
-	}
-      catch (IOException x)
-        {
-	  return null;
-	}
-
-    if (n < hdrVec.size())
-      return getField((String) hdrVec.elementAt(n));
-    return null;
-  }
-
-  // Override default method in URLConnection.
-  public String getHeaderFieldKey(int n)
-  {
-    if (!connected)
-      try
-        {
-	  connect();
-	}
-      catch (IOException x)
-        {
-	  return null;
-	}
-
-    if (n < hdrVec.size())
-      return getKey((String) hdrVec.elementAt(n));
-    return null;
-  }
-
-  private String getKey(String str)
-  {
-    if (str == null)
-      return null;
-    int index = str.indexOf(':');
-    if (index >= 0)
-      return str.substring(0, index);
-    else
-      return null;
-  }
-
-  private String getField(String str)
-  {
-    if (str == null)
-      return null;
-    int index = str.indexOf(':');
-    if (index >= 0)
-      return str.substring(index + 1).trim();
-    else
-      return str;
-  }
-
-  private void getHttpHeaders() throws IOException
-  {
-    // Originally tried using a BufferedReader here to take advantage of
-    // the readLine method and avoid the following, but the buffer read
-    // past the end of the headers so the first part of the content was lost.
-    // It is probably more robust than it needs to be, e.g. the byte[]
-    // is unlikely to overflow and a '\r' should always be followed by a '\n',
-    // but it is better to be safe just in case.
-    bufferedIn = new BufferedInputStream(sock.getInputStream());
-
-    int buflen = 100;
-    byte[] buf = new byte[buflen];
-    String line = "";
-    boolean gotnl = false;
-    byte[] ch = new byte[1];
-    ch[0] = (byte) '\n';
-
-    while (true)
-      {
-	// Check for leftover byte from non-'\n' after a '\r'.
-	if (ch[0] != '\n')
-	  line = line + '\r' + new String(ch, 0, 1);
-
-	int i;
-	// FIXME: This is rather inefficient.
-	for (i = 0; i < buflen; i++)
-	  {
-	    buf[i] = (byte) bufferedIn.read();
-	    if (buf[i] == -1)
-	      throw new IOException("Malformed HTTP header");
-	    if (buf[i] == '\r')
-	      {
-	        bufferedIn.read(ch, 0, 1);
-		if (ch[0] == '\n')
-		  gotnl = true;
-		break;
-	      }
-	  }
-	line = line + new String(buf, 0, i);
-
-	// A '\r' '\n' combo indicates the end of the header entry.
-	// If it wasn't found, cycle back through the loop and append
-	// to 'line' until one is found.
-	if (gotnl)
-	  {
-	    // A zero length entry signals the end of the headers.
-	    if (line.length() == 0)
-	      break;
-
-	    // Store the header and reinitialize for next cycle.
-	    hdrVec.addElement(line);
-	    String key = getKey(line);
-	    if (key != null)
-	      hdrHash.put(key.toLowerCase(), getField(line));
-	    line = "";
-	    ch[0] = (byte) '\n';
-	    gotnl = false;
-	  }
-      }
-  }
-}
Index: gnu/gcj/protocol/http/Handler.java
===================================================================
RCS file: gnu/gcj/protocol/http/Handler.java
diff -N gnu/gcj/protocol/http/Handler.java
--- gnu/gcj/protocol/http/Handler.java	8 Jun 2003 22:07:48 -0000	1.4
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,41 +0,0 @@
-// Handler.java - URLStreamHandler for http protocol.
-
-/* Copyright (C) 1999, 2003  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.http;
-
-import java.net.URL;
-import java.net.URLConnection;
-import java.net.URLStreamHandler;
-import java.io.IOException;
-
-/**
- * @author Warren Levy
- * @author Anthony Green <green@redhat.com>
- * @date March 26, 1999.
- */
-
-/**
- * Written using on-line Java Platform 1.2 API Specification, as well
- * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
- * Status:  Minimal functionality.
- */
-
-public class Handler extends URLStreamHandler
-{
-  protected URLConnection openConnection(URL url) throws IOException
-  {
-    return new Connection(url);
-  }
-
-  protected int getDefaultPort ()
-  {
-    return 80;
-  }
-}
Index: gnu/gcj/protocol/jar/Connection.java
===================================================================
RCS file: gnu/gcj/protocol/jar/Connection.java
diff -N gnu/gcj/protocol/jar/Connection.java
--- gnu/gcj/protocol/jar/Connection.java	9 Dec 2002 00:03:59 -0000	1.6
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,93 +0,0 @@
-/* Copyright (C) 1999, 2002  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.jar;
-
-import java.net.URL;
-import java.net.URLConnection;
-import java.net.JarURLConnection;
-import java.net.URLStreamHandler;
-import java.net.MalformedURLException;
-import java.net.ProtocolException;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.File;
-import java.io.FileOutputStream;
-import java.util.jar.JarFile;
-import java.util.zip.ZipFile;
-import java.util.Hashtable;
-
-/**
- * Written using on-line Java Platform 1.2 API Specification.
- *
- * @author Kresten Krab Thorup <krab@gnu.org>
- * @date Aug 10, 1999.
- */
-
-
-
-public class Connection extends JarURLConnection 
-{
-  static Hashtable file_cache = new Hashtable();
-  private JarFile jarfile;
-
-  public Connection(URL url)
-    throws MalformedURLException
-  {
-    super(url);
-  }
-
-  public synchronized JarFile getJarFile() throws java.io.IOException
-  {
-    if (!connected)
-      connect();
-
-    if (! doInput)
-      throw new ProtocolException("Can't open JarFile if doInput is false");
-
-    if (jarfile != null)
-      return jarfile;
-
-    URL jarFileURL = getJarFileURL ();
-
-    if (jarFileURL.getProtocol ().equals ("file")
-	&& jarFileURL.getHost ().equals (""))
-      {
-	if (getUseCaches())
-	  {
-	    jarfile = (JarFile) file_cache.get(jarFileURL);
-	    if (jarfile == null)
-	      {
-		jarfile = new JarFile (jarFileURL.getFile ());
-		file_cache.put (jarFileURL, jarfile);
-	      }
-	  }
-	else
-	  jarfile = new JarFile (jarFileURL.getFile ());
-      }
-    else
-      {
-	URLConnection urlconn = jarFileURL.openConnection();
-	InputStream is = urlconn.getInputStream();
-	byte[] buf = new byte[4*1024];
-	File f = File.createTempFile("cache", "jar");
-	FileOutputStream fos = new FileOutputStream(f);
-	int len = 0;
-	while((len = is.read(buf)) != -1)
-	  fos.write(buf, 0, len);
-        fos.close();
-	// Always verify the Manifest, open read only and delete when done.
-	// XXX ZipFile.OPEN_DELETE not yet implemented.
-	// jf = new JarFile(f, true, ZipFile.OPEN_READ | ZipFile.OPEN_DELETE);
-	jarfile = new JarFile(f, true, ZipFile.OPEN_READ);
-      }
-
-    return jarfile;
-  }
-
-}
Index: gnu/gcj/protocol/jar/Handler.java
===================================================================
RCS file: gnu/gcj/protocol/jar/Handler.java
diff -N gnu/gcj/protocol/jar/Handler.java
--- gnu/gcj/protocol/jar/Handler.java	7 Mar 2000 19:55:25 -0000	1.3
+++ /dev/null	1 Jan 1970 00:00:00 -0000
@@ -1,29 +0,0 @@
-// Handler.java - URLStreamHandler for file protocol.
-
-/* Copyright (C) 1999  Free Software Foundation
-
-   This file is part of libgcj.
-
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
-
-package gnu.gcj.protocol.jar;
-
-import java.net.URL;
-import java.net.URLConnection;
-import java.net.URLStreamHandler;
-import java.io.IOException;
-
-/**
- * @author Kresten Krab Thorup <krab@gnu.org>
- * @date August 13, 1999.
- */
-
-public class Handler extends URLStreamHandler
-{
-  protected URLConnection openConnection(URL url) throws IOException
-  {
-    return new Connection(url);
-  }
-}
Index: gnu/java/net/protocol/core/Connection.java
===================================================================
RCS file: gnu/java/net/protocol/core/Connection.java
diff -N gnu/java/net/protocol/core/Connection.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/core/Connection.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,172 @@
+// Connection.java - Implementation of URLConnection for core protocol.
+
+/* Copyright (C) 2001, 2003  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.core;
+
+import gnu.gcj.Core;
+import java.io.InputStream;
+import java.io.IOException;
+import java.net.ProtocolException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.util.Map;
+import java.util.Vector;
+import java.util.Hashtable;
+import java.util.Enumeration;
+
+/**
+ * @author Anthony Green <green@redhat.com>
+ * @date August 13, 2001
+ */
+
+class Connection extends URLConnection
+{
+  private Hashtable hdrHash = new Hashtable();
+  private Vector hdrVec = new Vector();
+  private boolean gotHeaders = false;
+
+  private Core core;
+
+  public Connection (URL url)
+  {
+    super(url);
+  }
+
+  // Implementation of abstract method.
+  public void connect() throws IOException
+  {
+    // Call is ignored if already connected.
+    if (connected)
+      return;
+
+    // If not connected, then file needs to be opened.
+    core = Core.create (url.getFile());
+    connected = true;
+  }
+
+  public InputStream getInputStream() throws IOException
+  {
+    if (!connected)
+      connect();
+
+    if (! doInput)
+      throw new ProtocolException("Can't open InputStream if doInput is false");
+    return new CoreInputStream (core);
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderField(String name)
+  {
+    try
+      {
+	getHeaders();
+      }
+    catch (IOException x)
+      {
+	return null;
+      }
+    return (String) hdrHash.get(name.toLowerCase());
+  }
+
+  // Override default method in URLConnection.
+  public Map getHeaderFields()
+  {
+    try
+      {
+	getHeaders();
+      }
+    catch (IOException x)
+      {
+	return null;
+      }
+    return hdrHash;
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderField(int n)
+  {
+    try
+      {
+	getHeaders();
+      }
+    catch (IOException x)
+      {
+	return null;
+      }
+    if (n < hdrVec.size())
+      return getField ((String) hdrVec.elementAt(n));
+
+    return null;
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderFieldKey(int n)
+  {
+    try
+      {
+	getHeaders();
+      }
+    catch (IOException x)
+      {
+	return null;
+      }
+    if (n < hdrVec.size())
+      return getKey ((String) hdrVec.elementAt(n));
+
+    return null;
+  }
+
+  private String getKey(String str)
+  {
+    if (str == null)
+      return null;
+    int index = str.indexOf(':');
+    if (index >= 0)
+      return str.substring(0, index);
+    else
+      return null;
+  }
+
+  private String getField(String str)
+  {
+    if (str == null)
+      return null;
+    int index = str.indexOf(':');
+    if (index >= 0)
+      return str.substring(index + 1).trim();
+    else
+      return str;
+  }
+
+  private void getHeaders() throws IOException
+  {
+    if (gotHeaders)
+      return;
+    gotHeaders = true;
+
+    connect();
+
+    // Yes, it is overkill to use the hash table and vector here since
+    // we're only putting one header in the file, but in case we need
+    // to add others later and for consistency, we'll implement it this way.
+
+    // Add the only header we know about right now:  Content-length.
+    long len = core.length;
+    String line = "Content-length: " + len;
+    hdrVec.addElement(line);
+
+    // The key will never be null in this scenario since we build up the
+    // headers ourselves.  If we ever rely on getting a header from somewhere
+    // else, then we may have to check if the result of getKey() is null.
+    String key = getKey(line);
+    hdrHash.put(key.toLowerCase(), Long.toString(len));
+  }
+}
+
Index: gnu/java/net/protocol/core/CoreInputStream.java
===================================================================
RCS file: gnu/java/net/protocol/core/CoreInputStream.java
diff -N gnu/java/net/protocol/core/CoreInputStream.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/core/CoreInputStream.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,90 @@
+// Handler.java - URLStreamHandler for core protocol.
+
+/* Copyright (C) 2001  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.core;
+
+import gnu.gcj.Core;
+import gnu.gcj.RawData;
+import java.io.InputStream;
+import java.io.IOException;
+
+public class CoreInputStream extends InputStream
+{
+  /* A pointer to the object in memory.  */
+  protected RawData ptr;
+
+  /* Position of the next byte in core to be read. */
+  protected int pos;
+
+  /* The currently marked position in the stream. */
+  protected int mark;
+
+  /* The index in core one greater than the last valid character. */
+  protected int count;
+
+  private native int unsafeGetByte (long offset);
+  private native int copyIntoByteArray (byte[] dest, int offset, int numBytes);
+
+  public CoreInputStream (Core core)
+  {
+    ptr = core.ptr;
+    count = core.length;
+  }
+
+  public synchronized int available()
+  {
+    return count - pos;
+  }
+
+  public synchronized void mark(int readAheadLimit)
+  {
+    // readAheadLimit is ignored per Java Class Lib. book, p.220.
+    mark = pos;
+  }
+
+  public boolean markSupported()
+  {
+    return true;
+  }
+
+  public synchronized int read()
+  {
+    if (pos < count)
+      return ((int) unsafeGetByte(pos++)) & 0xFF;
+    return -1;
+  }
+
+  public synchronized int read(byte[] b, int off, int len)
+  {
+    if (pos >= count)
+      return -1;
+
+    int numBytes = Math.min(count - pos, len);
+    copyIntoByteArray (b, off, numBytes);
+    pos += numBytes;
+    return numBytes;
+  }
+
+  public synchronized void reset()
+  {
+    pos = mark;
+  }
+
+  public synchronized long skip(long n)
+  {
+    // Even though the var numBytes is a long, in reality it can never
+    // be larger than an int since the result of subtracting 2 positive
+    // ints will always fit in an int.  Since we have to return a long
+    // anyway, numBytes might as well just be a long.
+    long numBytes = Math.min ((long) (count - pos), n < 0 ? 0L : n);
+    pos += numBytes;
+    return numBytes;
+  }
+}
Index: gnu/java/net/protocol/core/Handler.java
===================================================================
RCS file: gnu/java/net/protocol/core/Handler.java
diff -N gnu/java/net/protocol/core/Handler.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/core/Handler.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,28 @@
+// Handler.java - URLStreamHandler for core protocol.
+
+/* Copyright (C) 2001  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.core;
+
+import java.io.IOException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.net.URLStreamHandler;
+
+/**
+ * @author Anthony Green <green@redhat.com>
+ * @date August 13, 2001.
+ */
+public class Handler extends URLStreamHandler
+{
+  protected URLConnection openConnection(URL url) throws IOException
+  {
+    return new Connection(url);
+  }
+}
Index: gnu/java/net/protocol/core/natCoreInputStream.cc
===================================================================
RCS file: gnu/java/net/protocol/core/natCoreInputStream.cc
diff -N gnu/java/net/protocol/core/natCoreInputStream.cc
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/core/natCoreInputStream.cc	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,51 @@
+// natCoreInputStream.cc -- C++ side of CoreInputStream
+
+/* Copyright (C) 2001  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+/* Author: Anthony Green <green@redhat.com>.  */
+
+#include <config.h>
+
+#include <gcj/cni.h>
+#include <jvm.h>
+#include <string.h>
+
+#include <java/lang/NullPointerException.h>
+#include <java/lang/ArrayIndexOutOfBoundsException.h>
+#include <gnu/java/net/protocol/core/CoreInputStream.h>
+
+jint
+gnu::java::net::protocol::core::CoreInputStream::unsafeGetByte (jlong offset)
+{
+  return ((char*) ptr) [offset];
+}
+
+jint
+gnu::java::net::protocol::core::CoreInputStream::copyIntoByteArray (jbyteArray dest,
+							            jint offset,
+							            jint numBytes)
+{
+  if (!dest)
+    throw new ::java::lang::NullPointerException;
+  
+  jsize destSize = JvGetArrayLength (dest);
+  
+  if (offset < 0 || numBytes < 0 || offset + numBytes < 0
+      || offset + numBytes > destSize
+      || pos + numBytes > count)
+    throw new ::java::lang::ArrayIndexOutOfBoundsException;
+
+  void *pcore = (void *) &((char*) ptr) [pos];
+  void *pdest = (void *) (elements (dest) + offset);
+
+  memcpy (pdest, pcore, numBytes);
+
+  return 0;
+}
+
Index: gnu/java/net/protocol/file/Connection.java
===================================================================
RCS file: gnu/java/net/protocol/file/Connection.java
diff -N gnu/java/net/protocol/file/Connection.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/file/Connection.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,201 @@
+// Connection.java - Implementation of URLConnection for file protocol.
+
+/* Copyright (C) 1999  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.file;
+
+import java.io.BufferedInputStream;
+import java.io.BufferedOutputStream;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileOutputStream;
+import java.io.InputStream;
+import java.io.IOException;
+import java.io.OutputStream;
+import java.net.ProtocolException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.util.Map;
+import java.util.Vector;
+import java.util.Hashtable;
+import java.util.Enumeration;
+
+/**
+ * @author Warren Levy <warrenl@cygnus.com>
+ * @date April 13, 1999.
+ */
+
+/**
+ * Written using on-line Java Platform 1.2 API Specification, as well
+ * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
+ * Status:  Minimal subset of functionality.
+ */
+
+class Connection extends URLConnection
+{
+  private Hashtable hdrHash = new Hashtable();
+  private Vector hdrVec = new Vector();
+  private boolean gotHeaders = false;
+  private File fileIn;
+  private InputStream inputStream;
+  private OutputStream outputStream;
+
+  public Connection(URL url)
+  {
+    super(url);
+  }
+
+  // Implementation of abstract method.
+  public void connect() throws IOException
+  {
+    // Call is ignored if already connected.
+    if (connected)
+      return;
+
+    // If not connected, then file needs to be openned.
+    String fname = url.getFile();
+    fileIn = new File(fname);
+    if (doInput)
+      inputStream = new BufferedInputStream(new FileInputStream(fileIn));
+    if (doOutput)
+      outputStream = new BufferedOutputStream(new FileOutputStream(fileIn));
+    connected = true;
+  }
+
+  public InputStream getInputStream() throws IOException
+  {
+    if (! doInput)
+      throw new ProtocolException("Can't open InputStream if doInput is false");
+    if (!connected)
+      connect();
+
+    return inputStream;
+  }
+
+  // Override default method in URLConnection.
+  public OutputStream getOutputStream() throws IOException
+  {
+    if (! doOutput)
+      throw new
+	ProtocolException("Can't open OutputStream if doOutput is false");
+
+    if (!connected)
+      connect();
+
+    return outputStream;
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderField(String name)
+  {
+    try
+      {
+	getHeaders();
+      }
+    catch (IOException x)
+      {
+	return null;
+      }
+    return (String) hdrHash.get(name.toLowerCase());
+  }
+
+  // Override default method in URLConnection.
+  public Map getHeaderFields()
+  {
+    try
+      {
+	getHeaders();
+      }
+    catch (IOException x)
+      {
+	return null;
+      }
+    return hdrHash;
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderField(int n)
+  {
+    try
+      {
+	getHeaders();
+      }
+    catch (IOException x)
+      {
+	return null;
+      }
+    if (n < hdrVec.size())
+      return getField ((String) hdrVec.elementAt(n));
+
+    return null;
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderFieldKey(int n)
+  {
+    try
+      {
+	getHeaders();
+      }
+    catch (IOException x)
+      {
+	return null;
+      }
+    if (n < hdrVec.size())
+      return getKey ((String) hdrVec.elementAt(n));
+
+    return null;
+  }
+
+  private String getKey(String str)
+  {
+    if (str == null)
+      return null;
+    int index = str.indexOf(':');
+    if (index >= 0)
+      return str.substring(0, index);
+    else
+      return null;
+  }
+
+  private String getField(String str)
+  {
+    if (str == null)
+      return null;
+    int index = str.indexOf(':');
+    if (index >= 0)
+      return str.substring(index + 1).trim();
+    else
+      return str;
+  }
+
+  private void getHeaders() throws IOException
+  {
+    if (gotHeaders)
+      return;
+    gotHeaders = true;
+
+    connect();
+
+    // Yes, it is overkill to use the hash table and vector here since
+    // we're only putting one header in the file, but in case we need
+    // to add others later and for consistency, we'll implement it this way.
+
+    // Add the only header we know about right now:  Content-length.
+    long len = fileIn.length();
+    String line = "Content-length: " + len;
+    hdrVec.addElement(line);
+
+    // The key will never be null in this scenario since we build up the
+    // headers ourselves.  If we ever rely on getting a header from somewhere
+    // else, then we may have to check if the result of getKey() is null.
+    String key = getKey(line);
+    hdrHash.put(key.toLowerCase(), Long.toString(len));
+  }
+}
Index: gnu/java/net/protocol/file/Handler.java
===================================================================
RCS file: gnu/java/net/protocol/file/Handler.java
diff -N gnu/java/net/protocol/file/Handler.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/file/Handler.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,53 @@
+// Handler.java - URLStreamHandler for file protocol.
+
+/* Copyright (C) 1999, 2000  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.file;
+
+import java.io.IOException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.net.URLStreamHandler;
+
+/**
+ * @author Warren Levy <warrenl@cygnus.com>
+ * @date April 13, 1999.
+ */
+
+/**
+ * Written using on-line Java Platform 1.2 API Specification, as well
+ * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
+ * Status:  Minimal functionality.
+ */
+
+public class Handler extends URLStreamHandler
+{
+  protected URLConnection openConnection(URL url) throws IOException
+  {
+    // If a hostname is set, then we need to switch protocols to ftp
+    // in order to transfer this from the remote host.
+    String host = url.getHost();
+    if ((host != null) && (! host.equals("")))
+      {
+        throw new IOException("ftp protocol handler not yet implemented.");
+        /*
+	// Reset the protocol (and implicitly the handler) for this URL.
+	// Then have the URL attempt the connection again, as it will
+	// get the changed handler the next time around.
+	setURL (url, "ftp", url.getHost(), url.getPort(), url.getFile(),
+		url.getRef());
+	// Until the ftp protocol handler is written, this will cause
+	// a NullPointerException.
+	return url.openConnection();
+	*/
+      }
+
+    return new Connection(url);
+  }
+}
Index: gnu/java/net/protocol/gcjlib/Connection.java
===================================================================
RCS file: gnu/java/net/protocol/gcjlib/Connection.java
diff -N gnu/java/net/protocol/gcjlib/Connection.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/gcjlib/Connection.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,64 @@
+// Connection.java - Implementation of URLConnection for gcjlib
+// protocol.
+
+/* Copyright (C) 2003  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.gcjlib;
+
+import java.io.InputStream;
+import java.io.IOException;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.net.URLConnection;
+import gnu.gcj.Core;
+import gnu.gcj.runtime.SharedLibHelper;
+import gnu.java.net.protocol.core.CoreInputStream;
+
+/**
+ * @author Tom Tromey <tromey@redhat.com>
+ * @date January 10, 2003
+ */
+class Connection extends URLConnection
+{
+  String solib;
+  String name;
+  Core core;
+
+  public Connection (URL url) throws MalformedURLException
+  {
+    super (url);
+    int index = url.getFile().indexOf ("!/");
+    
+    if (index == -1)
+      throw new MalformedURLException ("couldn't find !/ in gcjlib URL");
+
+    name = url.getFile().substring (index + 2);
+    solib = url.getFile().substring (0, index);
+  }
+
+  public void connect() throws IOException
+  {
+    if (core != null)
+      return;
+    // We can't create a new SharedLibHelper here, since we don't know
+    // what parent class loader to use.
+    SharedLibHelper helper = SharedLibHelper.findHelper(solib);
+    if (helper == null)
+      throw new IOException("library not loaded: " + solib);
+    core = helper.findCore(name);
+    if (core == null)
+      throw new IOException("couldn't find core object: " + name);
+  }
+
+  public InputStream getInputStream() throws IOException
+  {
+    connect();
+    return new CoreInputStream(core);
+  }
+}
Index: gnu/java/net/protocol/gcjlib/Handler.java
===================================================================
RCS file: gnu/java/net/protocol/gcjlib/Handler.java
diff -N gnu/java/net/protocol/gcjlib/Handler.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/gcjlib/Handler.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,24 @@
+// Handler.java - URLStreamHandler for gcjlib protocol.
+
+/* Copyright (C) 2003  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.gcjlib;
+
+import java.io.IOException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.net.URLStreamHandler;
+
+public class Handler extends URLStreamHandler
+{
+  protected URLConnection openConnection (URL url) throws IOException
+  {
+    return new Connection (url);
+  }
+}
Index: gnu/java/net/protocol/http/Connection.java
===================================================================
RCS file: gnu/java/net/protocol/http/Connection.java
diff -N gnu/java/net/protocol/http/Connection.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/http/Connection.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,348 @@
+// Connection.java - Implementation of HttpURLConnection for http protocol.
+
+/* Copyright (C) 1999, 2000, 2003  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.http;
+
+import java.io.BufferedInputStream;
+import java.io.InputStream;
+import java.io.IOException;
+import java.io.OutputStream;
+import java.io.PrintWriter;
+import java.net.HttpURLConnection;
+import java.net.InetAddress;
+import java.net.ProtocolException;
+import java.net.Socket;
+import java.net.URL;
+import java.net.URLConnection;
+import java.util.Map;
+import java.util.Vector;
+import java.util.Hashtable;
+import java.util.Enumeration;
+
+/**
+ * Written using on-line Java Platform 1.2 API Specification, as well
+ * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
+ * Status: Minimal subset of functionality.  Proxies only partially
+ * handled; Redirects not yet handled.  FileNameMap handling needs to
+ * be considered.  useCaches, ifModifiedSince, and
+ * allowUserInteraction need consideration as well as doInput and
+ * doOutput.
+ */
+
+/**
+ * @author Warren Levy <warrenl@cygnus.com>
+ * @date March 29, 1999.
+ */
+class Connection extends HttpURLConnection
+{
+  protected Socket sock = null;
+  private static Hashtable defRequestProperties = new Hashtable();
+  private Hashtable requestProperties;
+  private Hashtable hdrHash = new Hashtable();
+  private Vector hdrVec = new Vector();
+  private BufferedInputStream bufferedIn;
+
+  private static int proxyPort = 80;
+  private static boolean proxyInUse = false;
+  private static String proxyHost = null;
+
+  static 
+  {
+    // Recognize some networking properties listed at
+    // http://java.sun.com/j2se/1.4/docs/guide/net/properties.html.
+    String port = null;
+    proxyHost = System.getProperty("http.proxyHost");
+    if (proxyHost != null)
+      {
+	proxyInUse = true;
+	if ((port = System.getProperty("http.proxyPort")) != null)
+	  {
+	    try
+	      {
+		proxyPort = Integer.parseInt(port);
+	      }
+	    catch (Throwable t)
+	      {
+		// Nothing.  
+	      }
+	  }
+      }
+  }
+
+  public Connection(URL url)
+  {
+    super(url);
+    requestProperties = (Hashtable) defRequestProperties.clone();
+  }
+
+  // Override method in URLConnection.
+  public static void setDefaultRequestProperty(String key, String value)
+  {
+    defRequestProperties.put(key, value);
+  }
+
+  // Override method in URLConnection.
+  public static String getDefaultRequestProperty(String key)
+  {
+    return (String) defRequestProperties.get(key);
+  }
+
+  // Override method in URLConnection.
+  public void setRequestProperty(String key, String value)
+  {
+    if (connected)
+      throw new IllegalAccessError("Connection already established.");
+
+    requestProperties.put(key, value);
+  }
+
+  // Override method in URLConnection.
+  public String getRequestProperty(String key)
+  {
+    if (connected)
+      throw new IllegalAccessError("Connection already established.");
+
+    return (String) requestProperties.get(key);
+  }
+
+  // Implementation of abstract method.
+  public void connect() throws IOException
+  {
+    // Call is ignored if already connected.
+    if (connected)
+      return;
+
+    // Get address and port number.
+    int port;
+    if (proxyInUse)
+      {
+	port = proxyPort;
+	sock = new Socket(proxyHost, port);
+      }
+    else
+      {
+	InetAddress destAddr = InetAddress.getByName(url.getHost());
+	if ((port = url.getPort()) == -1)
+	  port = 80;
+	// Open socket and output stream.
+	sock = new Socket(destAddr, port);
+      }
+
+    PrintWriter out = new PrintWriter(sock.getOutputStream());
+
+    // Send request including any request properties that were set.
+    out.print(getRequestMethod() + " " + url.getFile() + " HTTP/1.0\n");
+    out.print("Host: " + url.getHost() + ":" + port + "\n");
+    Enumeration reqKeys = requestProperties.keys();
+    Enumeration reqVals = requestProperties.elements();
+    while (reqKeys.hasMoreElements())
+      out.print(reqKeys.nextElement() + ": " + reqVals.nextElement() + "\n");
+    out.print("\n");
+    out.flush();    
+    getHttpHeaders();
+    connected = true;
+  }
+
+  // Implementation of abstract method.
+  public void disconnect()
+  {
+    if (sock != null)
+      {
+	try
+	  {
+	    sock.close();
+	  }
+	catch (IOException ex)
+	  {
+	    ; // Ignore errors in closing socket.
+	  }
+	sock = null;
+      }
+  }
+
+  public boolean usingProxy()
+  {
+    return proxyInUse;
+  }
+
+  // Override default method in URLConnection.
+  public InputStream getInputStream() throws IOException
+  {
+    if (!connected)
+      connect();
+
+    if (!doInput)
+      throw new ProtocolException("Can't open InputStream if doInput is false");
+    return bufferedIn;
+  }
+
+  // Override default method in URLConnection.
+  public OutputStream getOutputStream() throws IOException
+  {
+    if (!connected)
+      connect();
+
+    if (! doOutput)
+      throw new
+	ProtocolException("Can't open OutputStream if doOutput is false");
+    return sock.getOutputStream();
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderField(String name)
+  {
+    if (!connected)
+      try
+        {
+	  connect();
+	}
+      catch (IOException x)
+        {
+	  return null;
+	}
+
+    return (String) hdrHash.get(name.toLowerCase());
+  }
+
+  // Override default method in URLConnection.
+  public Map getHeaderFields()
+  {
+    if (!connected)
+      try
+        {
+	  connect();
+	}
+      catch (IOException x)
+        {
+	  return null;
+	}
+
+    return hdrHash;
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderField(int n)
+  {
+    if (!connected)
+      try
+        {
+	  connect();
+	}
+      catch (IOException x)
+        {
+	  return null;
+	}
+
+    if (n < hdrVec.size())
+      return getField ((String) hdrVec.elementAt(n));
+    return null;
+  }
+
+  // Override default method in URLConnection.
+  public String getHeaderFieldKey(int n)
+  {
+    if (!connected)
+      try
+        {
+	  connect();
+	}
+      catch (IOException x)
+        {
+	  return null;
+	}
+
+    if (n < hdrVec.size())
+      return getKey ((String) hdrVec.elementAt(n));
+    return null;
+  }
+
+  private String getKey(String str)
+  {
+    if (str == null)
+      return null;
+    int index = str.indexOf(':');
+    if (index >= 0)
+      return str.substring(0, index);
+    else
+      return null;
+  }
+
+  private String getField(String str)
+  {
+    if (str == null)
+      return null;
+    int index = str.indexOf(':');
+    if (index >= 0)
+      return str.substring(index + 1).trim();
+    else
+      return str;
+  }
+
+  private void getHttpHeaders() throws IOException
+  {
+    // Originally tried using a BufferedReader here to take advantage of
+    // the readLine method and avoid the following, but the buffer read
+    // past the end of the headers so the first part of the content was lost.
+    // It is probably more robust than it needs to be, e.g. the byte[]
+    // is unlikely to overflow and a '\r' should always be followed by a '\n',
+    // but it is better to be safe just in case.
+    bufferedIn = new BufferedInputStream(sock.getInputStream());
+
+    int buflen = 100;
+    byte[] buf = new byte[buflen];
+    String line = "";
+    boolean gotnl = false;
+    byte[] ch = new byte[1];
+    ch[0] = (byte) '\n';
+
+    while (true)
+      {
+	// Check for leftover byte from non-'\n' after a '\r'.
+	if (ch[0] != '\n')
+	  line = line + '\r' + new String(ch, 0, 1);
+
+	int i;
+	// FIXME: This is rather inefficient.
+	for (i = 0; i < buflen; i++)
+	  {
+	    buf[i] = (byte) bufferedIn.read();
+	    if (buf[i] == -1)
+	      throw new IOException("Malformed HTTP header");
+	    if (buf[i] == '\r')
+	      {
+	        bufferedIn.read(ch, 0, 1);
+		if (ch[0] == '\n')
+		  gotnl = true;
+		break;
+	      }
+	  }
+	line = line + new String(buf, 0, i);
+
+	// A '\r' '\n' combo indicates the end of the header entry.
+	// If it wasn't found, cycle back through the loop and append
+	// to 'line' until one is found.
+	if (gotnl)
+	  {
+	    // A zero length entry signals the end of the headers.
+	    if (line.length() == 0)
+	      break;
+
+	    // Store the header and reinitialize for next cycle.
+	    hdrVec.addElement(line);
+	    String key = getKey(line);
+	    if (key != null)
+	      hdrHash.put(key.toLowerCase(), getField(line));
+	    line = "";
+	    ch[0] = (byte) '\n';
+	    gotnl = false;
+	  }
+      }
+  }
+}
Index: gnu/java/net/protocol/http/Handler.java
===================================================================
RCS file: gnu/java/net/protocol/http/Handler.java
diff -N gnu/java/net/protocol/http/Handler.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/http/Handler.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,40 @@
+// Handler.java - URLStreamHandler for http protocol.
+
+/* Copyright (C) 1999, 2003  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.http;
+
+import java.io.IOException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.net.URLStreamHandler;
+
+/**
+ * Written using on-line Java Platform 1.2 API Specification, as well
+ * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
+ * Status:  Minimal functionality.
+ */
+
+/**
+ * @author Warren Levy
+ * @author Anthony Green <green@redhat.com>
+ * @date March 26, 1999.
+ */
+public class Handler extends URLStreamHandler
+{
+  protected URLConnection openConnection (URL url) throws IOException
+  {
+    return new Connection (url);
+  }
+
+  protected int getDefaultPort()
+  {
+    return 80;
+  }
+}
Index: gnu/java/net/protocol/jar/Connection.java
===================================================================
RCS file: gnu/java/net/protocol/jar/Connection.java
diff -N gnu/java/net/protocol/jar/Connection.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/jar/Connection.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,90 @@
+/* Copyright (C) 1999, 2002  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.jar;
+
+import java.io.InputStream;
+import java.io.IOException;
+import java.io.File;
+import java.io.FileOutputStream;
+import java.net.JarURLConnection;
+import java.net.MalformedURLException;
+import java.net.ProtocolException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.net.URLStreamHandler;
+import java.util.Hashtable;
+import java.util.jar.JarFile;
+import java.util.zip.ZipFile;
+
+/**
+ * Written using on-line Java Platform 1.2 API Specification.
+ *
+ * @author Kresten Krab Thorup <krab@gnu.org>
+ * @date Aug 10, 1999.
+ */
+public class Connection extends JarURLConnection 
+{
+  static Hashtable file_cache = new Hashtable();
+  private JarFile jarfile;
+
+  public Connection(URL url)
+    throws MalformedURLException
+  {
+    super(url);
+  }
+
+  public synchronized JarFile getJarFile() throws java.io.IOException
+  {
+    if (!connected)
+      connect();
+
+    if (! doInput)
+      throw new ProtocolException("Can't open JarFile if doInput is false");
+
+    if (jarfile != null)
+      return jarfile;
+
+    URL jarFileURL = getJarFileURL();
+
+    if (jarFileURL.getProtocol().equals ("file")
+	&& jarFileURL.getHost().equals (""))
+      {
+	if (getUseCaches())
+	  {
+	    jarfile = (JarFile) file_cache.get(jarFileURL);
+	    if (jarfile == null)
+	      {
+		jarfile = new JarFile (jarFileURL.getFile());
+		file_cache.put (jarFileURL, jarfile);
+	      }
+	  }
+	else
+	  jarfile = new JarFile (jarFileURL.getFile());
+      }
+    else
+      {
+	URLConnection urlconn = jarFileURL.openConnection();
+	InputStream is = urlconn.getInputStream();
+	byte[] buf = new byte[4*1024];
+	File f = File.createTempFile("cache", "jar");
+	FileOutputStream fos = new FileOutputStream(f);
+	int len = 0;
+	while ((len = is.read(buf)) != -1)
+	  fos.write(buf, 0, len);
+        fos.close();
+	// Always verify the Manifest, open read only and delete when done.
+	// XXX ZipFile.OPEN_DELETE not yet implemented.
+	// jf = new JarFile(f, true, ZipFile.OPEN_READ | ZipFile.OPEN_DELETE);
+	jarfile = new JarFile(f, true, ZipFile.OPEN_READ);
+      }
+
+    return jarfile;
+  }
+
+}
Index: gnu/java/net/protocol/jar/Handler.java
===================================================================
RCS file: gnu/java/net/protocol/jar/Handler.java
diff -N gnu/java/net/protocol/jar/Handler.java
--- /dev/null	1 Jan 1970 00:00:00 -0000
+++ gnu/java/net/protocol/jar/Handler.java	8 Oct 2003 16:26:24 -0000
@@ -0,0 +1,28 @@
+// Handler.java - URLStreamHandler for file protocol.
+
+/* Copyright (C) 1999  Free Software Foundation
+
+   This file is part of libgcj.
+
+This software is copyrighted work licensed under the terms of the
+Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
+details.  */
+
+package gnu.java.net.protocol.jar;
+
+import java.io.IOException;
+import java.net.URL;
+import java.net.URLConnection;
+import java.net.URLStreamHandler;
+
+/**
+ * @author Kresten Krab Thorup <krab@gnu.org>
+ * @date August 13, 1999.
+ */
+public class Handler extends URLStreamHandler
+{
+  protected URLConnection openConnection(URL url) throws IOException
+  {
+    return new Connection(url);
+  }
+}
Index: gnu/gcj/runtime/FirstThread.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/gnu/gcj/runtime/FirstThread.java,v
retrieving revision 1.11
diff -u -b -B -r1.11 FirstThread.java
--- gnu/gcj/runtime/FirstThread.java	1 Oct 2003 22:41:10 -0000	1.11
+++ gnu/gcj/runtime/FirstThread.java	8 Oct 2003 16:26:24 -0000
@@ -90,7 +90,7 @@
   // classes are only referred to via Class.forName(), so we add an
   // explicit mention of them here.
   static final Class Kcert = java.security.cert.Certificate.class;
-  static final Class Kfile = gnu.gcj.protocol.file.Handler.class;
-  static final Class Khttp = gnu.gcj.protocol.http.Handler.class;
-  static final Class Kjar  = gnu.gcj.protocol.jar.Handler.class;
+  static final Class Kfile = gnu.java.net.protocol.file.Handler.class;
+  static final Class Khttp = gnu.java.net.protocol.http.Handler.class;
+  static final Class Kjar  = gnu.java.net.protocol.jar.Handler.class;
 }
Index: java/net/URL.java
===================================================================
RCS file: /cvs/gcc/gcc/libjava/java/net/URL.java,v
retrieving revision 1.29
diff -u -b -B -r1.29 URL.java
--- java/net/URL.java	2 Oct 2003 12:16:52 -0000	1.29
+++ java/net/URL.java	8 Oct 2003 16:26:25 -0000
@@ -119,7 +119,7 @@
 public final class URL implements Serializable
 {
   private static final String DEFAULT_SEARCH_PATH =
-    "gnu.gcj.protocol|sun.net.www.protocol";
+    "gnu.java.net.protocol|sun.net.www.protocol";
   
   /**
    * The name of the protocol for this URL.
@@ -775,12 +775,12 @@
       }
     else if (protocol.equals ("core"))
       {
- 	ph = new gnu.gcj.protocol.core.Handler();
+ 	ph = new gnu.java.net.protocol.core.Handler();
       }
     else if (protocol.equals ("file"))
       {
 	// This is an interesting case.  It's tempting to think that we
 	// could call Class.forName ("gnu.gcj.protocol.file.Handler") to
 	// get the appropriate class.  Unfortunately, if we do that the
 	// program will never terminate, because getURLStreamHandler is
 	// eventually called by Class.forName.
@@ -789,7 +789,7 @@
 	// fix this problem.  If other protocols are required in a
 	// statically linked application they will need to be handled in
 	// the same way as "file".
-	ph = new gnu.gcj.protocol.file.Handler();
+	ph = new gnu.java.net.protocol.file.Handler();
       }
 
     // Non-default factory may have returned null or a factory wasn't set.
@@ -775,12 +775,12 @@
       {
 	// This is an interesting case.  It's tempting to think that we
-	// could call Class.forName ("gnu.gcj.protocol.file.Handler") to
+	// could call Class.forName ("gnu.java.net.protocol.file.Handler") to
 	// get the appropriate class.  Unfortunately, if we do that the
 	// program will never terminate, because getURLStreamHandler is

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]